# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPartnerResult',
    'AwaitableGetPartnerResult',
    'get_partner',
    'get_partner_output',
]

@pulumi.output_type
class GetPartnerResult:
    """
    A collection of values returned by getPartner.
    """
    def __init__(__self__, contact_email=None, created_at=None, id=None, logo_url=None, name=None, partner_id=None, portal_url=None, region=None, updated_at=None):
        if contact_email and not isinstance(contact_email, str):
            raise TypeError("Expected argument 'contact_email' to be a str")
        pulumi.set(__self__, "contact_email", contact_email)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if logo_url and not isinstance(logo_url, str):
            raise TypeError("Expected argument 'logo_url' to be a str")
        pulumi.set(__self__, "logo_url", logo_url)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if partner_id and not isinstance(partner_id, str):
            raise TypeError("Expected argument 'partner_id' to be a str")
        pulumi.set(__self__, "partner_id", partner_id)
        if portal_url and not isinstance(portal_url, str):
            raise TypeError("Expected argument 'portal_url' to be a str")
        pulumi.set(__self__, "portal_url", portal_url)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="contactEmail")
    def contact_email(self) -> _builtins.str:
        """
        Contact email address of the partner.
        """
        return pulumi.get(self, "contact_email")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Creation date of the partner.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="logoUrl")
    def logo_url(self) -> _builtins.str:
        """
        URL of the partner's logo.
        """
        return pulumi.get(self, "logo_url")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="partnerId")
    def partner_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "partner_id")

    @_builtins.property
    @pulumi.getter(name="portalUrl")
    def portal_url(self) -> _builtins.str:
        """
        URL of the partner's portal.
        """
        return pulumi.get(self, "portal_url")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Last update date of the partner.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetPartnerResult(GetPartnerResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPartnerResult(
            contact_email=self.contact_email,
            created_at=self.created_at,
            id=self.id,
            logo_url=self.logo_url,
            name=self.name,
            partner_id=self.partner_id,
            portal_url=self.portal_url,
            region=self.region,
            updated_at=self.updated_at)


def get_partner(name: Optional[_builtins.str] = None,
                partner_id: Optional[_builtins.str] = None,
                region: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPartnerResult:
    """
    Gets information about an Interlink Partner.

    A partner is an organization that provides shared connections at PoPs, allowing you to create hosted links without owning physical infrastructure.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a partner by its ID
    by_id = scaleway.interlink.get_partner(partner_id="fr-par/11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a partner by name
    by_name = scaleway.interlink.get_partner(name="FreePro")
    ```


    :param _builtins.str name: The name of the partner to filter for. Conflicts with `partner_id`.
    :param _builtins.str partner_id: The ID of the partner. Can be a plain UUID or a regional ID. Conflicts with `name`.
    :param _builtins.str region: `region`) The region in which the partner operates.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partnerId'] = partner_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:interlink/getPartner:getPartner', __args__, opts=opts, typ=GetPartnerResult).value

    return AwaitableGetPartnerResult(
        contact_email=pulumi.get(__ret__, 'contact_email'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        logo_url=pulumi.get(__ret__, 'logo_url'),
        name=pulumi.get(__ret__, 'name'),
        partner_id=pulumi.get(__ret__, 'partner_id'),
        portal_url=pulumi.get(__ret__, 'portal_url'),
        region=pulumi.get(__ret__, 'region'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_partner_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       partner_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPartnerResult]:
    """
    Gets information about an Interlink Partner.

    A partner is an organization that provides shared connections at PoPs, allowing you to create hosted links without owning physical infrastructure.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a partner by its ID
    by_id = scaleway.interlink.get_partner(partner_id="fr-par/11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve a partner by name
    by_name = scaleway.interlink.get_partner(name="FreePro")
    ```


    :param _builtins.str name: The name of the partner to filter for. Conflicts with `partner_id`.
    :param _builtins.str partner_id: The ID of the partner. Can be a plain UUID or a regional ID. Conflicts with `name`.
    :param _builtins.str region: `region`) The region in which the partner operates.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['partnerId'] = partner_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:interlink/getPartner:getPartner', __args__, opts=opts, typ=GetPartnerResult)
    return __ret__.apply(lambda __response__: GetPartnerResult(
        contact_email=pulumi.get(__response__, 'contact_email'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        logo_url=pulumi.get(__response__, 'logo_url'),
        name=pulumi.get(__response__, 'name'),
        partner_id=pulumi.get(__response__, 'partner_id'),
        portal_url=pulumi.get(__response__, 'portal_url'),
        region=pulumi.get(__response__, 'region'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'KeyRotationPolicyArgs',
    'KeyRotationPolicyArgsDict',
]

MYPY = False

if not MYPY:
    class KeyRotationPolicyArgsDict(TypedDict):
        rotation_period: pulumi.Input[_builtins.str]
        """
        – The period between key rotations (e.g., `"720h"` for 30 days).
        """
        next_rotation_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The date and time of the next scheduled rotation.
        """
elif False:
    KeyRotationPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class KeyRotationPolicyArgs:
    def __init__(__self__, *,
                 rotation_period: pulumi.Input[_builtins.str],
                 next_rotation_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] rotation_period: – The period between key rotations (e.g., `"720h"` for 30 days).
        :param pulumi.Input[_builtins.str] next_rotation_at: The date and time of the next scheduled rotation.
        """
        pulumi.set(__self__, "rotation_period", rotation_period)
        if next_rotation_at is not None:
            pulumi.set(__self__, "next_rotation_at", next_rotation_at)

    @_builtins.property
    @pulumi.getter(name="rotationPeriod")
    def rotation_period(self) -> pulumi.Input[_builtins.str]:
        """
        – The period between key rotations (e.g., `"720h"` for 30 days).
        """
        return pulumi.get(self, "rotation_period")

    @rotation_period.setter
    def rotation_period(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rotation_period", value)

    @_builtins.property
    @pulumi.getter(name="nextRotationAt")
    def next_rotation_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the next scheduled rotation.
        """
        return pulumi.get(self, "next_rotation_at")

    @next_rotation_at.setter
    def next_rotation_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "next_rotation_at", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IpCustomResourceArgs',
    'IpCustomResourceArgsDict',
    'IpResourceArgs',
    'IpResourceArgsDict',
    'IpReverseArgs',
    'IpReverseArgsDict',
    'IpSourceArgs',
    'IpSourceArgsDict',
    'GetIpResourceArgs',
    'GetIpResourceArgsDict',
    'GetIpsResourceArgs',
    'GetIpsResourceArgsDict',
]

MYPY = False

if not MYPY:
    class IpCustomResourceArgsDict(TypedDict):
        mac_address: pulumi.Input[_builtins.str]
        """
        The MAC address of the custom resource.
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        When the resource is in a Private Network, a DNS record is available to resolve the resource name.
        """
elif False:
    IpCustomResourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpCustomResourceArgs:
    def __init__(__self__, *,
                 mac_address: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] mac_address: The MAC address of the custom resource.
        :param pulumi.Input[_builtins.str] name: When the resource is in a Private Network, a DNS record is available to resolve the resource name.
        """
        pulumi.set(__self__, "mac_address", mac_address)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> pulumi.Input[_builtins.str]:
        """
        The MAC address of the custom resource.
        """
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "mac_address", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        When the resource is in a Private Network, a DNS record is available to resolve the resource name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class IpResourceArgsDict(TypedDict):
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the resource that the IP is attached to.
        """
        mac_address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The MAC address of the resource the IP is attached to.
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the resource the IP is attached to.
        """
        type: NotRequired[pulumi.Input[_builtins.str]]
        """
        The type of resource the IP is attached to.
        """
elif False:
    IpResourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpResourceArgs:
    def __init__(__self__, *,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 mac_address: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] id: The ID of the resource that the IP is attached to.
        :param pulumi.Input[_builtins.str] mac_address: The MAC address of the resource the IP is attached to.
        :param pulumi.Input[_builtins.str] name: The name of the resource the IP is attached to.
        :param pulumi.Input[_builtins.str] type: The type of resource the IP is attached to.
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if mac_address is not None:
            pulumi.set(__self__, "mac_address", mac_address)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the resource that the IP is attached to.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter(name="macAddress")
    def mac_address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The MAC address of the resource the IP is attached to.
        """
        return pulumi.get(self, "mac_address")

    @mac_address.setter
    def mac_address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mac_address", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the resource the IP is attached to.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of resource the IP is attached to.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


if not MYPY:
    class IpReverseArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The IP corresponding to the hostname
        """
        hostname: NotRequired[pulumi.Input[_builtins.str]]
        """
        The reverse domain name.
        """
elif False:
    IpReverseArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpReverseArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 hostname: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The IP corresponding to the hostname
        :param pulumi.Input[_builtins.str] hostname: The reverse domain name.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP corresponding to the hostname
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The reverse domain name.
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hostname", value)


if not MYPY:
    class IpSourceArgsDict(TypedDict):
        private_network_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The Private Network of the IP (if the IP is a private IP).
        """
        subnet_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The Private Network subnet of the IP (if the IP is a private IP).
        """
        zonal: NotRequired[pulumi.Input[_builtins.str]]
        """
        The zone of the IP (if the IP is public and zoned, rather than private and/or regional)
        """
elif False:
    IpSourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpSourceArgs:
    def __init__(__self__, *,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 zonal: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] private_network_id: The Private Network of the IP (if the IP is a private IP).
        :param pulumi.Input[_builtins.str] subnet_id: The Private Network subnet of the IP (if the IP is a private IP).
        :param pulumi.Input[_builtins.str] zonal: The zone of the IP (if the IP is public and zoned, rather than private and/or regional)
        """
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if zonal is not None:
            pulumi.set(__self__, "zonal", zonal)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Private Network of the IP (if the IP is a private IP).
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Private Network subnet of the IP (if the IP is a private IP).
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @_builtins.property
    @pulumi.getter
    def zonal(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The zone of the IP (if the IP is public and zoned, rather than private and/or regional)
        """
        return pulumi.get(self, "zonal")

    @zonal.setter
    def zonal(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zonal", value)


if not MYPY:
    class GetIpResourceArgsDict(TypedDict):
        type: _builtins.str
        """
        The type of the resource the IP is attached to. [Documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/ipam/v1#pkg-constants) with type list.
        """
        id: NotRequired[_builtins.str]
        """
        The ID of the resource that the IP is attached to.
        """
        name: NotRequired[_builtins.str]
        """
        The name of the resource the IP is attached to.
        """
elif False:
    GetIpResourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetIpResourceArgs:
    def __init__(__self__, *,
                 type: _builtins.str,
                 id: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None):
        """
        :param _builtins.str type: The type of the resource the IP is attached to. [Documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/ipam/v1#pkg-constants) with type list.
        :param _builtins.str id: The ID of the resource that the IP is attached to.
        :param _builtins.str name: The name of the resource the IP is attached to.
        """
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the resource the IP is attached to. [Documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/ipam/v1#pkg-constants) with type list.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: _builtins.str):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the resource that the IP is attached to.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[_builtins.str]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the resource the IP is attached to.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[_builtins.str]):
        pulumi.set(self, "name", value)


if not MYPY:
    class GetIpsResourceArgsDict(TypedDict):
        type: _builtins.str
        """
        The type of the attached resource. [Documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/ipam/v1#pkg-constants) with type list.
        """
        id: NotRequired[_builtins.str]
        """
        The ID of the attached resource.
        """
        name: NotRequired[_builtins.str]
        """
        The name of the attached resource.
        """
elif False:
    GetIpsResourceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GetIpsResourceArgs:
    def __init__(__self__, *,
                 type: _builtins.str,
                 id: Optional[_builtins.str] = None,
                 name: Optional[_builtins.str] = None):
        """
        :param _builtins.str type: The type of the attached resource. [Documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/ipam/v1#pkg-constants) with type list.
        :param _builtins.str id: The ID of the attached resource.
        :param _builtins.str name: The name of the attached resource.
        """
        pulumi.set(__self__, "type", type)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the attached resource. [Documentation](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/ipam/v1#pkg-constants) with type list.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: _builtins.str):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the attached resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[_builtins.str]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        The name of the attached resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[_builtins.str]):
        pulumi.set(self, "name", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DeploymentEndpoint',
    'DeploymentEndpointService',
    'DeploymentPrivateNetwork',
    'DeploymentVolume',
    'GetDeploymentEndpointResult',
    'GetDeploymentEndpointServiceResult',
    'GetDeploymentPrivateNetworkResult',
    'GetDeploymentVolumeResult',
]

@pulumi.output_type
class DeploymentEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "privateNetworkId":
            suggest = "private_network_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 id: Optional[_builtins.str] = None,
                 private_network_id: Optional[_builtins.str] = None,
                 public: Optional[_builtins.bool] = None,
                 services: Optional[Sequence['outputs.DeploymentEndpointService']] = None):
        """
        :param _builtins.str id: The ID of the endpoint.
        :param _builtins.str private_network_id: Private network ID if the endpoint is private.
        :param _builtins.bool public: Whether the endpoint is public (true) or private (false).
        :param Sequence['DeploymentEndpointServiceArgs'] services: List of services exposed on the endpoint.
        """
        if id is not None:
            pulumi.set(__self__, "id", id)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if public is not None:
            pulumi.set(__self__, "public", public)
        if services is not None:
            pulumi.set(__self__, "services", services)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the endpoint.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[_builtins.str]:
        """
        Private network ID if the endpoint is private.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter
    def public(self) -> Optional[_builtins.bool]:
        """
        Whether the endpoint is public (true) or private (false).
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter
    def services(self) -> Optional[Sequence['outputs.DeploymentEndpointService']]:
        """
        List of services exposed on the endpoint.
        """
        return pulumi.get(self, "services")


@pulumi.output_type
class DeploymentEndpointService(dict):
    def __init__(__self__, *,
                 name: Optional[_builtins.str] = None,
                 port: Optional[_builtins.int] = None,
                 url: Optional[_builtins.str] = None):
        """
        :param _builtins.str name: Name of the OpenSearch deployment. If not specified, a random name will be generated.
        :param _builtins.int port: Service port number.
        :param _builtins.str url: Full URL to access the service (e.g., "https://abc-123.searchdb.fr-par.scw.cloud:9200").
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the OpenSearch deployment. If not specified, a random name will be generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        Service port number.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[_builtins.str]:
        """
        Full URL to access the service (e.g., "https://abc-123.searchdb.fr-par.scw.cloud:9200").
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class DeploymentPrivateNetwork(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "privateNetworkId":
            suggest = "private_network_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentPrivateNetwork. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentPrivateNetwork.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentPrivateNetwork.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 private_network_id: _builtins.str):
        """
        :param _builtins.str private_network_id: Private network ID if the endpoint is private.
        """
        pulumi.set(__self__, "private_network_id", private_network_id)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        Private network ID if the endpoint is private.
        """
        return pulumi.get(self, "private_network_id")


@pulumi.output_type
class DeploymentVolume(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "sizeInGb":
            suggest = "size_in_gb"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentVolume. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentVolume.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentVolume.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 size_in_gb: _builtins.int,
                 type: _builtins.str):
        """
        :param _builtins.int size_in_gb: Volume size in GB. Changing this forces recreation of the deployment.
        :param _builtins.str type: Volume type. Valid values are `sbs_5k` (5K IOPS) or `sbs_15k` (15K IOPS). Changing this forces recreation of the deployment.
        """
        pulumi.set(__self__, "size_in_gb", size_in_gb)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> _builtins.int:
        """
        Volume size in GB. Changing this forces recreation of the deployment.
        """
        return pulumi.get(self, "size_in_gb")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Volume type. Valid values are `sbs_5k` (5K IOPS) or `sbs_15k` (15K IOPS). Changing this forces recreation of the deployment.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetDeploymentEndpointResult(dict):
    def __init__(__self__, *,
                 id: _builtins.str,
                 private_network_id: _builtins.str,
                 public: _builtins.bool,
                 services: Sequence['outputs.GetDeploymentEndpointServiceResult']):
        """
        :param _builtins.str id: Endpoint ID
        :param _builtins.str private_network_id: Private network ID if applicable
        :param _builtins.bool public: Whether the endpoint is public
        :param Sequence['GetDeploymentEndpointServiceArgs'] services: List of services
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "private_network_id", private_network_id)
        pulumi.set(__self__, "public", public)
        pulumi.set(__self__, "services", services)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Endpoint ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        Private network ID if applicable
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter
    def public(self) -> _builtins.bool:
        """
        Whether the endpoint is public
        """
        return pulumi.get(self, "public")

    @_builtins.property
    @pulumi.getter
    def services(self) -> Sequence['outputs.GetDeploymentEndpointServiceResult']:
        """
        List of services
        """
        return pulumi.get(self, "services")


@pulumi.output_type
class GetDeploymentEndpointServiceResult(dict):
    def __init__(__self__, *,
                 name: _builtins.str,
                 port: _builtins.int,
                 url: _builtins.str):
        """
        :param _builtins.str name: The name of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
        :param _builtins.int port: Service port
        :param _builtins.str url: Service URL
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        Service port
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def url(self) -> _builtins.str:
        """
        Service URL
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class GetDeploymentPrivateNetworkResult(dict):
    def __init__(__self__, *,
                 private_network_id: _builtins.str):
        """
        :param _builtins.str private_network_id: UUID of the Private Network
        """
        pulumi.set(__self__, "private_network_id", private_network_id)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> _builtins.str:
        """
        UUID of the Private Network
        """
        return pulumi.get(self, "private_network_id")


@pulumi.output_type
class GetDeploymentVolumeResult(dict):
    def __init__(__self__, *,
                 size_in_gb: _builtins.int,
                 type: _builtins.str):
        """
        :param _builtins.int size_in_gb: Volume size in GB
        :param _builtins.str type: Volume type (sbs_5k, sbs_15k)
        """
        pulumi.set(__self__, "size_in_gb", size_in_gb)
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="sizeInGb")
    def size_in_gb(self) -> _builtins.int:
        """
        Volume size in GB
        """
        return pulumi.get(self, "size_in_gb")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Volume type (sbs_5k, sbs_15k)
        """
        return pulumi.get(self, "type")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DeviceCertificate',
    'DeviceMessageFilters',
    'DeviceMessageFiltersPublish',
    'DeviceMessageFiltersSubscribe',
    'RouteDatabase',
    'RouteRest',
    'RouteS3',
    'GetDeviceCertificateResult',
    'GetDeviceMessageFilterResult',
    'GetDeviceMessageFilterPublishResult',
    'GetDeviceMessageFilterSubscribeResult',
]

@pulumi.output_type
class DeviceCertificate(dict):
    def __init__(__self__, *,
                 crt: Optional[_builtins.str] = None,
                 key: Optional[_builtins.str] = None):
        """
        :param _builtins.str crt: X509 PEM encoded certificate of the device
        :param _builtins.str key: The private key of the device, in case it is generated by Scaleway.
        """
        if crt is not None:
            pulumi.set(__self__, "crt", crt)
        if key is not None:
            pulumi.set(__self__, "key", key)

    @_builtins.property
    @pulumi.getter
    def crt(self) -> Optional[_builtins.str]:
        """
        X509 PEM encoded certificate of the device
        """
        return pulumi.get(self, "crt")

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[_builtins.str]:
        """
        The private key of the device, in case it is generated by Scaleway.
        """
        return pulumi.get(self, "key")


@pulumi.output_type
class DeviceMessageFilters(dict):
    def __init__(__self__, *,
                 publish: Optional['outputs.DeviceMessageFiltersPublish'] = None,
                 subscribe: Optional['outputs.DeviceMessageFiltersSubscribe'] = None):
        """
        :param 'DeviceMessageFiltersPublishArgs' publish: Rules used to restrict topics the device can publish to.
        :param 'DeviceMessageFiltersSubscribeArgs' subscribe: Rules used to restrict topics the device can subscribe to.
        """
        if publish is not None:
            pulumi.set(__self__, "publish", publish)
        if subscribe is not None:
            pulumi.set(__self__, "subscribe", subscribe)

    @_builtins.property
    @pulumi.getter
    def publish(self) -> Optional['outputs.DeviceMessageFiltersPublish']:
        """
        Rules used to restrict topics the device can publish to.
        """
        return pulumi.get(self, "publish")

    @_builtins.property
    @pulumi.getter
    def subscribe(self) -> Optional['outputs.DeviceMessageFiltersSubscribe']:
        """
        Rules used to restrict topics the device can subscribe to.
        """
        return pulumi.get(self, "subscribe")


@pulumi.output_type
class DeviceMessageFiltersPublish(dict):
    def __init__(__self__, *,
                 policy: Optional[_builtins.str] = None,
                 topics: Optional[Sequence[_builtins.str]] = None):
        """
        :param _builtins.str policy: Filtering policy (eg `accept` or `reject`)
        :param Sequence[_builtins.str] topics: List of topics to match (eg `foo/bar/+/baz/#`)
        """
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if topics is not None:
            pulumi.set(__self__, "topics", topics)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional[_builtins.str]:
        """
        Filtering policy (eg `accept` or `reject`)
        """
        return pulumi.get(self, "policy")

    @_builtins.property
    @pulumi.getter
    def topics(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of topics to match (eg `foo/bar/+/baz/#`)
        """
        return pulumi.get(self, "topics")


@pulumi.output_type
class DeviceMessageFiltersSubscribe(dict):
    def __init__(__self__, *,
                 policy: Optional[_builtins.str] = None,
                 topics: Optional[Sequence[_builtins.str]] = None):
        """
        :param _builtins.str policy: Same as publish rules.
        :param Sequence[_builtins.str] topics: Same as publish rules.
               
               - `certificate.crt` - (Optional) The certificate of the device, either generated by Scaleway or provided.
               
               > **Important:** Updates to `certificate.crt` will disconnect connected devices and the previous certificate will be deleted and won't be recoverable.
        """
        if policy is not None:
            pulumi.set(__self__, "policy", policy)
        if topics is not None:
            pulumi.set(__self__, "topics", topics)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> Optional[_builtins.str]:
        """
        Same as publish rules.
        """
        return pulumi.get(self, "policy")

    @_builtins.property
    @pulumi.getter
    def topics(self) -> Optional[Sequence[_builtins.str]]:
        """
        Same as publish rules.

        - `certificate.crt` - (Optional) The certificate of the device, either generated by Scaleway or provided.

        > **Important:** Updates to `certificate.crt` will disconnect connected devices and the previous certificate will be deleted and won't be recoverable.
        """
        return pulumi.get(self, "topics")


@pulumi.output_type
class RouteDatabase(dict):
    def __init__(__self__, *,
                 dbname: _builtins.str,
                 host: _builtins.str,
                 password: _builtins.str,
                 port: _builtins.int,
                 query: _builtins.str,
                 username: _builtins.str):
        """
        :param _builtins.str dbname: The database name (e.g. `measurements`).
        :param _builtins.str host: The database hostname. Can be an IP or a FQDN.
        :param _builtins.str password: The database password.
        :param _builtins.int port: The database port (e.g. `5432`)
        :param _builtins.str query: The SQL query that will be executed when receiving a message ($TOPIC and $PAYLOAD variables are available, see documentation, e.g. `INSERT INTO mytable(date, topic, value) VALUES (NOW(), $TOPIC, $PAYLOAD)`).
        :param _builtins.str username: The database username.
        """
        pulumi.set(__self__, "dbname", dbname)
        pulumi.set(__self__, "host", host)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "query", query)
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter
    def dbname(self) -> _builtins.str:
        """
        The database name (e.g. `measurements`).
        """
        return pulumi.get(self, "dbname")

    @_builtins.property
    @pulumi.getter
    def host(self) -> _builtins.str:
        """
        The database hostname. Can be an IP or a FQDN.
        """
        return pulumi.get(self, "host")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        """
        The database password.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The database port (e.g. `5432`)
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def query(self) -> _builtins.str:
        """
        The SQL query that will be executed when receiving a message ($TOPIC and $PAYLOAD variables are available, see documentation, e.g. `INSERT INTO mytable(date, topic, value) VALUES (NOW(), $TOPIC, $PAYLOAD)`).
        """
        return pulumi.get(self, "query")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        The database username.
        """
        return pulumi.get(self, "username")


@pulumi.output_type
class RouteRest(dict):
    def __init__(__self__, *,
                 headers: Mapping[str, _builtins.str],
                 uri: _builtins.str,
                 verb: _builtins.str):
        """
        :param Mapping[str, _builtins.str] headers: a map of the extra headers to send with the HTTP call (e.g. `X-Header = Value`).
        :param _builtins.str uri: The URI of the Rest endpoint (e.g. `https://internal.mycompany.com/ingest/mqttdata`).
        :param _builtins.str verb: The HTTP Verb used to call Rest URI (e.g. `post`).
        """
        pulumi.set(__self__, "headers", headers)
        pulumi.set(__self__, "uri", uri)
        pulumi.set(__self__, "verb", verb)

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Mapping[str, _builtins.str]:
        """
        a map of the extra headers to send with the HTTP call (e.g. `X-Header = Value`).
        """
        return pulumi.get(self, "headers")

    @_builtins.property
    @pulumi.getter
    def uri(self) -> _builtins.str:
        """
        The URI of the Rest endpoint (e.g. `https://internal.mycompany.com/ingest/mqttdata`).
        """
        return pulumi.get(self, "uri")

    @_builtins.property
    @pulumi.getter
    def verb(self) -> _builtins.str:
        """
        The HTTP Verb used to call Rest URI (e.g. `post`).
        """
        return pulumi.get(self, "verb")


@pulumi.output_type
class RouteS3(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bucketName":
            suggest = "bucket_name"
        elif key == "bucketRegion":
            suggest = "bucket_region"
        elif key == "objectPrefix":
            suggest = "object_prefix"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in RouteS3. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        RouteS3.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        RouteS3.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bucket_name: _builtins.str,
                 bucket_region: _builtins.str,
                 strategy: _builtins.str,
                 object_prefix: Optional[_builtins.str] = None):
        """
        :param _builtins.str bucket_name: The name of the S3 route's destination bucket (e.g. `my-object-storage`).
        :param _builtins.str bucket_region: The region of the S3 route's destination bucket (e.g. `fr-par`).
        :param _builtins.str strategy: How the S3 route's objects will be created (e.g. `per_topic`). See [documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for behaviour details.
        :param _builtins.str object_prefix: The string to prefix object names with (e.g. `mykeyprefix-`).
        """
        pulumi.set(__self__, "bucket_name", bucket_name)
        pulumi.set(__self__, "bucket_region", bucket_region)
        pulumi.set(__self__, "strategy", strategy)
        if object_prefix is not None:
            pulumi.set(__self__, "object_prefix", object_prefix)

    @_builtins.property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> _builtins.str:
        """
        The name of the S3 route's destination bucket (e.g. `my-object-storage`).
        """
        return pulumi.get(self, "bucket_name")

    @_builtins.property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> _builtins.str:
        """
        The region of the S3 route's destination bucket (e.g. `fr-par`).
        """
        return pulumi.get(self, "bucket_region")

    @_builtins.property
    @pulumi.getter
    def strategy(self) -> _builtins.str:
        """
        How the S3 route's objects will be created (e.g. `per_topic`). See [documentation](https://www.scaleway.com/en/docs/iot-hub/how-to/create-route/) for behaviour details.
        """
        return pulumi.get(self, "strategy")

    @_builtins.property
    @pulumi.getter(name="objectPrefix")
    def object_prefix(self) -> Optional[_builtins.str]:
        """
        The string to prefix object names with (e.g. `mykeyprefix-`).
        """
        return pulumi.get(self, "object_prefix")


@pulumi.output_type
class GetDeviceCertificateResult(dict):
    def __init__(__self__, *,
                 crt: _builtins.str,
                 key: _builtins.str):
        """
        :param _builtins.str crt: X509 PEM encoded certificate of the device
        :param _builtins.str key: X509 PEM encoded key of the device
        """
        pulumi.set(__self__, "crt", crt)
        pulumi.set(__self__, "key", key)

    @_builtins.property
    @pulumi.getter
    def crt(self) -> _builtins.str:
        """
        X509 PEM encoded certificate of the device
        """
        return pulumi.get(self, "crt")

    @_builtins.property
    @pulumi.getter
    def key(self) -> _builtins.str:
        """
        X509 PEM encoded key of the device
        """
        return pulumi.get(self, "key")


@pulumi.output_type
class GetDeviceMessageFilterResult(dict):
    def __init__(__self__, *,
                 publishes: Sequence['outputs.GetDeviceMessageFilterPublishResult'],
                 subscribes: Sequence['outputs.GetDeviceMessageFilterSubscribeResult']):
        """
        :param Sequence['GetDeviceMessageFilterPublishArgs'] publishes: Rule to restrict topics the device can publish to
        :param Sequence['GetDeviceMessageFilterSubscribeArgs'] subscribes: Rule to restrict topics the device can subscribe to
        """
        pulumi.set(__self__, "publishes", publishes)
        pulumi.set(__self__, "subscribes", subscribes)

    @_builtins.property
    @pulumi.getter
    def publishes(self) -> Sequence['outputs.GetDeviceMessageFilterPublishResult']:
        """
        Rule to restrict topics the device can publish to
        """
        return pulumi.get(self, "publishes")

    @_builtins.property
    @pulumi.getter
    def subscribes(self) -> Sequence['outputs.GetDeviceMessageFilterSubscribeResult']:
        """
        Rule to restrict topics the device can subscribe to
        """
        return pulumi.get(self, "subscribes")


@pulumi.output_type
class GetDeviceMessageFilterPublishResult(dict):
    def __init__(__self__, *,
                 policy: _builtins.str,
                 topics: Sequence[_builtins.str]):
        """
        :param _builtins.str policy: Publish message filter policy
        :param Sequence[_builtins.str] topics: List of topics in the set
        """
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "topics", topics)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> _builtins.str:
        """
        Publish message filter policy
        """
        return pulumi.get(self, "policy")

    @_builtins.property
    @pulumi.getter
    def topics(self) -> Sequence[_builtins.str]:
        """
        List of topics in the set
        """
        return pulumi.get(self, "topics")


@pulumi.output_type
class GetDeviceMessageFilterSubscribeResult(dict):
    def __init__(__self__, *,
                 policy: _builtins.str,
                 topics: Sequence[_builtins.str]):
        """
        :param _builtins.str policy: Subscribe message filter policy
        :param Sequence[_builtins.str] topics: List of topics in the set
        """
        pulumi.set(__self__, "policy", policy)
        pulumi.set(__self__, "topics", topics)

    @_builtins.property
    @pulumi.getter
    def policy(self) -> _builtins.str:
        """
        Subscribe message filter policy
        """
        return pulumi.get(self, "policy")

    @_builtins.property
    @pulumi.getter
    def topics(self) -> Sequence[_builtins.str]:
        """
        List of topics in the set
        """
        return pulumi.get(self, "topics")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ClusterPrivateNetwork',
    'ClusterPublicNetwork',
    'GetClusterPrivateNetworkResult',
    'GetClusterPublicNetworkResult',
]

@pulumi.output_type
class ClusterPrivateNetwork(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "pnId":
            suggest = "pn_id"
        elif key == "dnsRecords":
            suggest = "dns_records"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterPrivateNetwork. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterPrivateNetwork.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterPrivateNetwork.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 pn_id: _builtins.str,
                 dns_records: Optional[Sequence[_builtins.str]] = None,
                 id: Optional[_builtins.str] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param _builtins.str pn_id: The private network ID (same as input).
        :param Sequence[_builtins.str] dns_records: List of DNS records for the private endpoint.
        :param _builtins.str id: The ID of the private endpoint.
        :param _builtins.int port: TCP port number.
        """
        pulumi.set(__self__, "pn_id", pn_id)
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="pnId")
    def pn_id(self) -> _builtins.str:
        """
        The private network ID (same as input).
        """
        return pulumi.get(self, "pn_id")

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of DNS records for the private endpoint.
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the private endpoint.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        TCP port number.
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class ClusterPublicNetwork(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dnsRecords":
            suggest = "dns_records"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterPublicNetwork. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterPublicNetwork.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterPublicNetwork.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 dns_records: Optional[Sequence[_builtins.str]] = None,
                 id: Optional[_builtins.str] = None,
                 port: Optional[_builtins.int] = None):
        """
        :param Sequence[_builtins.str] dns_records: List of DNS records for the private endpoint.
        :param _builtins.str id: The ID of the private endpoint.
        :param _builtins.int port: TCP port number.
        """
        if dns_records is not None:
            pulumi.set(__self__, "dns_records", dns_records)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if port is not None:
            pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Optional[Sequence[_builtins.str]]:
        """
        List of DNS records for the private endpoint.
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        The ID of the private endpoint.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[_builtins.int]:
        """
        TCP port number.
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetClusterPrivateNetworkResult(dict):
    def __init__(__self__, *,
                 dns_records: Sequence[_builtins.str],
                 id: _builtins.str,
                 pn_id: _builtins.str,
                 port: _builtins.int):
        """
        :param Sequence[_builtins.str] dns_records: DNS records for the private endpoint
        :param _builtins.str id: The endpoint ID
        :param _builtins.str pn_id: The private network ID
        :param _builtins.int port: TCP port number
        """
        pulumi.set(__self__, "dns_records", dns_records)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "pn_id", pn_id)
        pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Sequence[_builtins.str]:
        """
        DNS records for the private endpoint
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The endpoint ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="pnId")
    def pn_id(self) -> _builtins.str:
        """
        The private network ID
        """
        return pulumi.get(self, "pn_id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        TCP port number
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetClusterPublicNetworkResult(dict):
    def __init__(__self__, *,
                 dns_records: Sequence[_builtins.str],
                 id: _builtins.str,
                 port: _builtins.int):
        """
        :param Sequence[_builtins.str] dns_records: DNS records for the public endpoint
        :param _builtins.str id: ID of the public endpoint
        :param _builtins.int port: TCP port number
        """
        pulumi.set(__self__, "dns_records", dns_records)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "port", port)

    @_builtins.property
    @pulumi.getter(name="dnsRecords")
    def dns_records(self) -> Sequence[_builtins.str]:
        """
        DNS records for the public endpoint
        """
        return pulumi.get(self, "dns_records")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        ID of the public endpoint
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        TCP port number
        """
        return pulumi.get(self, "port")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DatabaseArgs', 'Database']

@pulumi.input_type
class DatabaseArgs:
    def __init__(__self__, *,
                 deployment_id: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Database resource.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this database belongs.
        :param pulumi.Input[_builtins.str] name: Name of the database.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the database should be created.
        """
        pulumi.set(__self__, "deployment_id", deployment_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the Data Warehouse deployment to which this database belongs.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "deployment_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the database.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the database should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _DatabaseState:
    def __init__(__self__, *,
                 deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering Database resources.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this database belongs.
        :param pulumi.Input[_builtins.str] name: Name of the database.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the database should be created.
        :param pulumi.Input[_builtins.int] size: Size of the database in GB.
        """
        if deployment_id is not None:
            pulumi.set(__self__, "deployment_id", deployment_id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the Data Warehouse deployment to which this database belongs.
        """
        return pulumi.get(self, "deployment_id")

    @deployment_id.setter
    def deployment_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "deployment_id", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the database.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the database should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Size of the database in GB.
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "size", value)


@pulumi.type_token("scaleway:datawarehouse/database:Database")
class Database(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Data Warehouse databases within a deployment.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/data-warehouse/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.datawarehouse.Deployment("main",
            name="my-datawarehouse",
            version="v25",
            replica_count=1,
            cpu_min=2,
            cpu_max=4,
            ram_per_cpu=4,
            password="thiZ_is_v&ry_s3cret")
        main_database = scaleway.datawarehouse.Database("main",
            deployment_id=main.id,
            name="my_database")
        ```

        ## Import

        Data Warehouse databases can be imported using the `{region}/{deployment_id}/{name}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:datawarehouse/database:Database main fr-par/11111111-1111-1111-1111-111111111111/my_database
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this database belongs.
        :param pulumi.Input[_builtins.str] name: Name of the database.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the database should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Data Warehouse databases within a deployment.
        For more information refer to the [product documentation](https://www.scaleway.com/en/docs/data-warehouse/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.datawarehouse.Deployment("main",
            name="my-datawarehouse",
            version="v25",
            replica_count=1,
            cpu_min=2,
            cpu_max=4,
            ram_per_cpu=4,
            password="thiZ_is_v&ry_s3cret")
        main_database = scaleway.datawarehouse.Database("main",
            deployment_id=main.id,
            name="my_database")
        ```

        ## Import

        Data Warehouse databases can be imported using the `{region}/{deployment_id}/{name}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:datawarehouse/database:Database main fr-par/11111111-1111-1111-1111-111111111111/my_database
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseArgs.__new__(DatabaseArgs)

            if deployment_id is None and not opts.urn:
                raise TypeError("Missing required property 'deployment_id'")
            __props__.__dict__["deployment_id"] = deployment_id
            __props__.__dict__["name"] = name
            __props__.__dict__["region"] = region
            __props__.__dict__["size"] = None
        super(Database, __self__).__init__(
            'scaleway:datawarehouse/database:Database',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            size: Optional[pulumi.Input[_builtins.int]] = None) -> 'Database':
        """
        Get an existing Database resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] deployment_id: ID of the Data Warehouse deployment to which this database belongs.
        :param pulumi.Input[_builtins.str] name: Name of the database.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the database should be created.
        :param pulumi.Input[_builtins.int] size: Size of the database in GB.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseState.__new__(_DatabaseState)

        __props__.__dict__["deployment_id"] = deployment_id
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["size"] = size
        return Database(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the Data Warehouse deployment to which this database belongs.
        """
        return pulumi.get(self, "deployment_id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the database.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the database should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Output[_builtins.int]:
        """
        Size of the database in GB.
        """
        return pulumi.get(self, "size")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServerIpArgs',
    'ServerIpArgsDict',
    'ServerIpv4Args',
    'ServerIpv4ArgsDict',
    'ServerIpv6Args',
    'ServerIpv6ArgsDict',
    'ServerOptionArgs',
    'ServerOptionArgsDict',
    'ServerPrivateIpArgs',
    'ServerPrivateIpArgsDict',
    'ServerPrivateNetworkArgs',
    'ServerPrivateNetworkArgsDict',
]

MYPY = False

if not MYPY:
    class ServerIpArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The address of the IPv6.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the IPv6.
        """
        reverse: NotRequired[pulumi.Input[_builtins.str]]
        """
        The reverse of the IPv6.
        """
        version: NotRequired[pulumi.Input[_builtins.str]]
        """
        The type of the IPv6.
        """
elif False:
    ServerIpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerIpArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 reverse: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The address of the IPv6.
        :param pulumi.Input[_builtins.str] id: The ID of the IPv6.
        :param pulumi.Input[_builtins.str] reverse: The reverse of the IPv6.
        :param pulumi.Input[_builtins.str] version: The type of the IPv6.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if reverse is not None:
            pulumi.set(__self__, "reverse", reverse)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The address of the IPv6.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPv6.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def reverse(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The reverse of the IPv6.
        """
        return pulumi.get(self, "reverse")

    @reverse.setter
    def reverse(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reverse", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the IPv6.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class ServerIpv4ArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The address of the IPv6.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the IPv6.
        """
        reverse: NotRequired[pulumi.Input[_builtins.str]]
        """
        The reverse of the IPv6.
        """
        version: NotRequired[pulumi.Input[_builtins.str]]
        """
        The type of the IPv6.
        """
elif False:
    ServerIpv4ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerIpv4Args:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 reverse: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The address of the IPv6.
        :param pulumi.Input[_builtins.str] id: The ID of the IPv6.
        :param pulumi.Input[_builtins.str] reverse: The reverse of the IPv6.
        :param pulumi.Input[_builtins.str] version: The type of the IPv6.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if reverse is not None:
            pulumi.set(__self__, "reverse", reverse)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The address of the IPv6.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPv6.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def reverse(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The reverse of the IPv6.
        """
        return pulumi.get(self, "reverse")

    @reverse.setter
    def reverse(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reverse", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the IPv6.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class ServerIpv6ArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The address of the IPv6.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the IPv6.
        """
        reverse: NotRequired[pulumi.Input[_builtins.str]]
        """
        The reverse of the IPv6.
        """
        version: NotRequired[pulumi.Input[_builtins.str]]
        """
        The type of the IPv6.
        """
elif False:
    ServerIpv6ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerIpv6Args:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None,
                 reverse: Optional[pulumi.Input[_builtins.str]] = None,
                 version: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The address of the IPv6.
        :param pulumi.Input[_builtins.str] id: The ID of the IPv6.
        :param pulumi.Input[_builtins.str] reverse: The reverse of the IPv6.
        :param pulumi.Input[_builtins.str] version: The type of the IPv6.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if reverse is not None:
            pulumi.set(__self__, "reverse", reverse)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The address of the IPv6.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPv6.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter
    def reverse(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The reverse of the IPv6.
        """
        return pulumi.get(self, "reverse")

    @reverse.setter
    def reverse(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "reverse", value)

    @_builtins.property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the IPv6.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class ServerOptionArgsDict(TypedDict):
        id: pulumi.Input[_builtins.str]
        """
        The id of the option to enable. Use [this endpoint](https://www.scaleway.com/en/developers/api/elastic-metal/#path-options-list-options) to find the available options IDs.
        """
        expires_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The auto expiration date for compatible options
        """
        name: NotRequired[pulumi.Input[_builtins.str]]
        """
        The name of the server.
        """
elif False:
    ServerOptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerOptionArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[_builtins.str],
                 expires_at: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] id: The id of the option to enable. Use [this endpoint](https://www.scaleway.com/en/developers/api/elastic-metal/#path-options-list-options) to find the available options IDs.
        :param pulumi.Input[_builtins.str] expires_at: The auto expiration date for compatible options
        :param pulumi.Input[_builtins.str] name: The name of the server.
        """
        pulumi.set(__self__, "id", id)
        if expires_at is not None:
            pulumi.set(__self__, "expires_at", expires_at)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the option to enable. Use [this endpoint](https://www.scaleway.com/en/developers/api/elastic-metal/#path-options-list-options) to find the available options IDs.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter(name="expiresAt")
    def expires_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The auto expiration date for compatible options
        """
        return pulumi.get(self, "expires_at")

    @expires_at.setter
    def expires_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expires_at", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the server.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class ServerPrivateIpArgsDict(TypedDict):
        address: NotRequired[pulumi.Input[_builtins.str]]
        """
        The address of the IPv6.
        """
        id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the IPv6.
        """
elif False:
    ServerPrivateIpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerPrivateIpArgs:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] address: The address of the IPv6.
        :param pulumi.Input[_builtins.str] id: The ID of the IPv6.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The address of the IPv6.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPv6.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "id", value)


if not MYPY:
    class ServerPrivateNetworkArgsDict(TypedDict):
        id: pulumi.Input[_builtins.str]
        """
        The id of the private network to attach.
        """
        created_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The date and time of the creation of the private network.
        """
        ipam_ip_ids: NotRequired[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]
        """
        List of IPAM IP IDs to assign to the server in the requested private network.
        """
        mapping_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the Server-to-Private Network mapping.
        """
        status: NotRequired[pulumi.Input[_builtins.str]]
        """
        The private network status.
        """
        updated_at: NotRequired[pulumi.Input[_builtins.str]]
        """
        The date and time of the last update of the private network.
        """
        vlan: NotRequired[pulumi.Input[_builtins.int]]
        """
        The VLAN ID associated to the private network.
        """
elif False:
    ServerPrivateNetworkArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerPrivateNetworkArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[_builtins.str],
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_ip_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 mapping_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 vlan: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] id: The id of the private network to attach.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the private network.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ipam_ip_ids: List of IPAM IP IDs to assign to the server in the requested private network.
        :param pulumi.Input[_builtins.str] mapping_id: The ID of the Server-to-Private Network mapping.
        :param pulumi.Input[_builtins.str] status: The private network status.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the private network.
        :param pulumi.Input[_builtins.int] vlan: The VLAN ID associated to the private network.
        """
        pulumi.set(__self__, "id", id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if ipam_ip_ids is not None:
            pulumi.set(__self__, "ipam_ip_ids", ipam_ip_ids)
        if mapping_id is not None:
            pulumi.set(__self__, "mapping_id", mapping_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if vlan is not None:
            pulumi.set(__self__, "vlan", vlan)

    @_builtins.property
    @pulumi.getter
    def id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the private network to attach.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the private network.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="ipamIpIds")
    def ipam_ip_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of IPAM IP IDs to assign to the server in the requested private network.
        """
        return pulumi.get(self, "ipam_ip_ids")

    @ipam_ip_ids.setter
    def ipam_ip_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ipam_ip_ids", value)

    @_builtins.property
    @pulumi.getter(name="mappingId")
    def mapping_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Server-to-Private Network mapping.
        """
        return pulumi.get(self, "mapping_id")

    @mapping_id.setter
    def mapping_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mapping_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The private network status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the private network.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter
    def vlan(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The VLAN ID associated to the private network.
        """
        return pulumi.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "vlan", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'DeploymentPrivateEndpoint',
    'DeploymentPrivateIp',
    'DeploymentPublicEndpoint',
    'ModelNodesSupport',
    'ModelNodesSupportQuantization',
    'GetModelNodesSupportResult',
    'GetModelNodesSupportQuantizationResult',
]

@pulumi.output_type
class DeploymentPrivateEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "disableAuth":
            suggest = "disable_auth"
        elif key == "privateNetworkId":
            suggest = "private_network_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentPrivateEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentPrivateEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentPrivateEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 disable_auth: Optional[_builtins.bool] = None,
                 id: Optional[_builtins.str] = None,
                 private_network_id: Optional[_builtins.str] = None,
                 url: Optional[_builtins.str] = None):
        """
        :param _builtins.bool disable_auth: Disable the authentication on the endpoint.
        :param _builtins.str id: (Optional) The id of the public endpoint.
        :param _builtins.str private_network_id: The ID of the private network to use.
        :param _builtins.str url: (Optional) The URL of the endpoint.
        """
        if disable_auth is not None:
            pulumi.set(__self__, "disable_auth", disable_auth)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="disableAuth")
    def disable_auth(self) -> Optional[_builtins.bool]:
        """
        Disable the authentication on the endpoint.
        """
        return pulumi.get(self, "disable_auth")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        (Optional) The id of the public endpoint.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[_builtins.str]:
        """
        The ID of the private network to use.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[_builtins.str]:
        """
        (Optional) The URL of the endpoint.
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class DeploymentPrivateIp(dict):
    def __init__(__self__, *,
                 address: Optional[_builtins.str] = None,
                 id: Optional[_builtins.str] = None):
        """
        :param _builtins.str address: The private IPv4 address.
        :param _builtins.str id: (Optional) The id of the public endpoint.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if id is not None:
            pulumi.set(__self__, "id", id)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[_builtins.str]:
        """
        The private IPv4 address.
        """
        return pulumi.get(self, "address")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        (Optional) The id of the public endpoint.
        """
        return pulumi.get(self, "id")


@pulumi.output_type
class DeploymentPublicEndpoint(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "disableAuth":
            suggest = "disable_auth"
        elif key == "isEnabled":
            suggest = "is_enabled"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in DeploymentPublicEndpoint. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        DeploymentPublicEndpoint.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        DeploymentPublicEndpoint.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 disable_auth: Optional[_builtins.bool] = None,
                 id: Optional[_builtins.str] = None,
                 is_enabled: Optional[_builtins.bool] = None,
                 url: Optional[_builtins.str] = None):
        """
        :param _builtins.bool disable_auth: Disable the authentication on the endpoint.
        :param _builtins.str id: (Optional) The id of the public endpoint.
        :param _builtins.bool is_enabled: Enable or disable public endpoint.
        :param _builtins.str url: (Optional) The URL of the endpoint.
        """
        if disable_auth is not None:
            pulumi.set(__self__, "disable_auth", disable_auth)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter(name="disableAuth")
    def disable_auth(self) -> Optional[_builtins.bool]:
        """
        Disable the authentication on the endpoint.
        """
        return pulumi.get(self, "disable_auth")

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        (Optional) The id of the public endpoint.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[_builtins.bool]:
        """
        Enable or disable public endpoint.
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[_builtins.str]:
        """
        (Optional) The URL of the endpoint.
        """
        return pulumi.get(self, "url")


@pulumi.output_type
class ModelNodesSupport(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "nodeTypeName":
            suggest = "node_type_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ModelNodesSupport. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ModelNodesSupport.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ModelNodesSupport.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 node_type_name: Optional[_builtins.str] = None,
                 quantizations: Optional[Sequence['outputs.ModelNodesSupportQuantization']] = None):
        """
        :param _builtins.str node_type_name: The type of node supported.
        :param Sequence['ModelNodesSupportQuantizationArgs'] quantizations: A list of supported quantization options, including:
        """
        if node_type_name is not None:
            pulumi.set(__self__, "node_type_name", node_type_name)
        if quantizations is not None:
            pulumi.set(__self__, "quantizations", quantizations)

    @_builtins.property
    @pulumi.getter(name="nodeTypeName")
    def node_type_name(self) -> Optional[_builtins.str]:
        """
        The type of node supported.
        """
        return pulumi.get(self, "node_type_name")

    @_builtins.property
    @pulumi.getter
    def quantizations(self) -> Optional[Sequence['outputs.ModelNodesSupportQuantization']]:
        """
        A list of supported quantization options, including:
        """
        return pulumi.get(self, "quantizations")


@pulumi.output_type
class ModelNodesSupportQuantization(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "maxContextSize":
            suggest = "max_context_size"
        elif key == "quantizationBits":
            suggest = "quantization_bits"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ModelNodesSupportQuantization. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ModelNodesSupportQuantization.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ModelNodesSupportQuantization.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 allowed: Optional[_builtins.bool] = None,
                 max_context_size: Optional[_builtins.int] = None,
                 quantization_bits: Optional[_builtins.int] = None):
        """
        :param _builtins.bool allowed: Whether this quantization is allowed.
        :param _builtins.int max_context_size: Maximum context length supported by this quantization.
        :param _builtins.int quantization_bits: Number of bits used for quantization (e.g., 8, 16).
        """
        if allowed is not None:
            pulumi.set(__self__, "allowed", allowed)
        if max_context_size is not None:
            pulumi.set(__self__, "max_context_size", max_context_size)
        if quantization_bits is not None:
            pulumi.set(__self__, "quantization_bits", quantization_bits)

    @_builtins.property
    @pulumi.getter
    def allowed(self) -> Optional[_builtins.bool]:
        """
        Whether this quantization is allowed.
        """
        return pulumi.get(self, "allowed")

    @_builtins.property
    @pulumi.getter(name="maxContextSize")
    def max_context_size(self) -> Optional[_builtins.int]:
        """
        Maximum context length supported by this quantization.
        """
        return pulumi.get(self, "max_context_size")

    @_builtins.property
    @pulumi.getter(name="quantizationBits")
    def quantization_bits(self) -> Optional[_builtins.int]:
        """
        Number of bits used for quantization (e.g., 8, 16).
        """
        return pulumi.get(self, "quantization_bits")


@pulumi.output_type
class GetModelNodesSupportResult(dict):
    def __init__(__self__, *,
                 node_type_name: _builtins.str,
                 quantizations: Sequence['outputs.GetModelNodesSupportQuantizationResult']):
        """
        :param _builtins.str node_type_name: The type of node supported.
        :param Sequence['GetModelNodesSupportQuantizationArgs'] quantizations: A list of supported quantization options, including:
        """
        pulumi.set(__self__, "node_type_name", node_type_name)
        pulumi.set(__self__, "quantizations", quantizations)

    @_builtins.property
    @pulumi.getter(name="nodeTypeName")
    def node_type_name(self) -> _builtins.str:
        """
        The type of node supported.
        """
        return pulumi.get(self, "node_type_name")

    @_builtins.property
    @pulumi.getter
    def quantizations(self) -> Sequence['outputs.GetModelNodesSupportQuantizationResult']:
        """
        A list of supported quantization options, including:
        """
        return pulumi.get(self, "quantizations")


@pulumi.output_type
class GetModelNodesSupportQuantizationResult(dict):
    def __init__(__self__, *,
                 allowed: _builtins.bool,
                 max_context_size: _builtins.int,
                 quantization_bits: _builtins.int):
        """
        :param _builtins.bool allowed: Whether this quantization is allowed.
        :param _builtins.int max_context_size: Maximum context length supported by this quantization.
        :param _builtins.int quantization_bits: Number of bits used for quantization (e.g., 8, 16).
        """
        pulumi.set(__self__, "allowed", allowed)
        pulumi.set(__self__, "max_context_size", max_context_size)
        pulumi.set(__self__, "quantization_bits", quantization_bits)

    @_builtins.property
    @pulumi.getter
    def allowed(self) -> _builtins.bool:
        """
        Whether this quantization is allowed.
        """
        return pulumi.get(self, "allowed")

    @_builtins.property
    @pulumi.getter(name="maxContextSize")
    def max_context_size(self) -> _builtins.int:
        """
        Maximum context length supported by this quantization.
        """
        return pulumi.get(self, "max_context_size")

    @_builtins.property
    @pulumi.getter(name="quantizationBits")
    def quantization_bits(self) -> _builtins.int:
        """
        Number of bits used for quantization (e.g., 8, 16).
        """
        return pulumi.get(self, "quantization_bits")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CustomerGatewayArgs', 'CustomerGateway']

@pulumi.input_type
class CustomerGatewayArgs:
    def __init__(__self__, *,
                 asn: pulumi.Input[_builtins.int],
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a CustomerGateway resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        """
        pulumi.set(__self__, "asn", asn)
        if ipv4_public is not None:
            pulumi.set(__self__, "ipv4_public", ipv4_public)
        if ipv6_public is not None:
            pulumi.set(__self__, "ipv6_public", ipv6_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> pulumi.Input[_builtins.int]:
        """
        The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "asn", value)

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv4 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv4_public")

    @ipv4_public.setter
    def ipv4_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv4_public", value)

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv6 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv6_public")

    @ipv6_public.setter
    def ipv6_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_public", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the customer gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the customer gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the customer gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the customer gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _CustomerGatewayState:
    def __init__(__self__, *,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering CustomerGateway resources.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the customer gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        if asn is not None:
            pulumi.set(__self__, "asn", asn)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if ipv4_public is not None:
            pulumi.set(__self__, "ipv4_public", ipv4_public)
        if ipv6_public is not None:
            pulumi.set(__self__, "ipv6_public", ipv6_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        """
        return pulumi.get(self, "asn")

    @asn.setter
    def asn(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "asn", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv4 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv4_public")

    @ipv4_public.setter
    def ipv4_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv4_public", value)

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The public IPv6 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv6_public")

    @ipv6_public.setter
    def ipv6_public(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipv6_public", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the customer gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the customer gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the customer gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`) The region in which the customer gateway should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags to apply to the customer gateway.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("scaleway:s2svpn/customerGateway:CustomerGateway")
class CustomerGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Site-to-Site VPN Customer Gateways.
        A customer gateway represents your external VPN endpoint (e.g., a firewall, router, or VPN appliance).

        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            asn=65000)
        ```

        ### With IPv6

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            ipv6_public="2001:db8::1",
            asn=65000)
        ```

        ### Using Instance Public IP

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpn_endpoint_ip = scaleway.instance.Ip("vpn_endpoint_ip")
        vpn_endpoint = scaleway.instance.Server("vpn_endpoint",
            name="vpn-endpoint",
            type="DEV1-S",
            image="ubuntu_jammy",
            ip_ids=[vpn_endpoint_ip.id])
        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public=vpn_endpoint_ip.address,
            asn=65000)
        ```

        ## Import

        Customer Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/customerGateway:CustomerGateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CustomerGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Site-to-Site VPN Customer Gateways.
        A customer gateway represents your external VPN endpoint (e.g., a firewall, router, or VPN appliance).

        For more information, see [the main documentation](https://www.scaleway.com/en/docs/site-to-site-vpn/reference-content/understanding-s2svpn/).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            asn=65000)
        ```

        ### With IPv6

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public="203.0.113.1",
            ipv6_public="2001:db8::1",
            asn=65000)
        ```

        ### Using Instance Public IP

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        vpn_endpoint_ip = scaleway.instance.Ip("vpn_endpoint_ip")
        vpn_endpoint = scaleway.instance.Server("vpn_endpoint",
            name="vpn-endpoint",
            type="DEV1-S",
            image="ubuntu_jammy",
            ip_ids=[vpn_endpoint_ip.id])
        customer_gw = scaleway.s2svpn.CustomerGateway("customer_gw",
            name="my-customer-gateway",
            ipv4_public=vpn_endpoint_ip.address,
            asn=65000)
        ```

        ## Import

        Customer Gateways can be imported using `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:s2svpn/customerGateway:CustomerGateway main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param CustomerGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CustomerGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 asn: Optional[pulumi.Input[_builtins.int]] = None,
                 ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
                 ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CustomerGatewayArgs.__new__(CustomerGatewayArgs)

            if asn is None and not opts.urn:
                raise TypeError("Missing required property 'asn'")
            __props__.__dict__["asn"] = asn
            __props__.__dict__["ipv4_public"] = ipv4_public
            __props__.__dict__["ipv6_public"] = ipv6_public
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["updated_at"] = None
        super(CustomerGateway, __self__).__init__(
            'scaleway:s2svpn/customerGateway:CustomerGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            asn: Optional[pulumi.Input[_builtins.int]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            ipv4_public: Optional[pulumi.Input[_builtins.str]] = None,
            ipv6_public: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'CustomerGateway':
        """
        Get an existing CustomerGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] asn: The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the customer gateway (RFC 3339 format).
        :param pulumi.Input[_builtins.str] ipv4_public: The public IPv4 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] ipv6_public: The public IPv6 address of the customer gateway (your VPN endpoint).
        :param pulumi.Input[_builtins.str] name: The name of the customer gateway. If not provided, it will be randomly generated.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the customer gateway is associated with.
        :param pulumi.Input[_builtins.str] region: `region`) The region in which the customer gateway should be created.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags to apply to the customer gateway.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CustomerGatewayState.__new__(_CustomerGatewayState)

        __props__.__dict__["asn"] = asn
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["ipv4_public"] = ipv4_public
        __props__.__dict__["ipv6_public"] = ipv6_public
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return CustomerGateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def asn(self) -> pulumi.Output[_builtins.int]:
        """
        The AS Number of the customer gateway. Must be different from Scaleway's ASN (12876). For testing, you can use a private ASN (64512-65535).
        """
        return pulumi.get(self, "asn")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="ipv4Public")
    def ipv4_public(self) -> pulumi.Output[_builtins.str]:
        """
        The public IPv4 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv4_public")

    @_builtins.property
    @pulumi.getter(name="ipv6Public")
    def ipv6_public(self) -> pulumi.Output[_builtins.str]:
        """
        The public IPv6 address of the customer gateway (your VPN endpoint).
        """
        return pulumi.get(self, "ipv6_public")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the customer gateway. If not provided, it will be randomly generated.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the customer gateway is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the customer gateway is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`) The region in which the customer gateway should be created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of tags to apply to the customer gateway.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the customer gateway (RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")

